==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ConnectionMonitorEndpointFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ConnectionMonitorEndpointFilterType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes the connection monitor endpoint filter.
 * @property items List of items in the filter.
 * @property type The behavior of the endpoint filter. Currently only 'Include' is supported.
 */
public data class ConnectionMonitorEndpointFilterArgs(
    public val items: Output<List<ConnectionMonitorEndpointFilterItemArgs>>? = null,
    public val type: Output<Either<String, ConnectionMonitorEndpointFilterType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterArgs =
        com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectionMonitorEndpointFilterArgs].
 */
@PulumiTagMarker
public class ConnectionMonitorEndpointFilterArgsBuilder internal constructor() {
    private var items: Output<List<ConnectionMonitorEndpointFilterItemArgs>>? = null

    private var type: Output<Either<String, ConnectionMonitorEndpointFilterType>>? = null

    /**
     * @param value List of items in the filter.
     */
    @JvmName("gifmxiavirsywndi")
    public suspend fun items(`value`: Output<List<ConnectionMonitorEndpointFilterItemArgs>>) {
        this.items = value
    }

    @JvmName("cfwmnsmhtkrlqvox")
    public suspend fun items(vararg values: Output<ConnectionMonitorEndpointFilterItemArgs>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values List of items in the filter.
     */
    @JvmName("vbfumdctbjodkuvg")
    public suspend fun items(values: List<Output<ConnectionMonitorEndpointFilterItemArgs>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value The behavior of the endpoint filter. Currently only 'Include' is supported.
     */
    @JvmName("vhrmooybnrnkbwdu")
    public suspend fun type(`value`: Output<Either<String, ConnectionMonitorEndpointFilterType>>) {
        this.type = value
    }

    /**
     * @param value List of items in the filter.
     */
    @JvmName("qfufnmhevjpaillu")
    public suspend fun items(`value`: List<ConnectionMonitorEndpointFilterItemArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param argument List of items in the filter.
     */
    @JvmName("opfmgopegffonanu")
    public suspend
    fun items(argument: List<suspend ConnectionMonitorEndpointFilterItemArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConnectionMonitorEndpointFilterItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument List of items in the filter.
     */
    @JvmName("cgqygicfmnfvchjx")
    public suspend fun items(
        vararg
        argument: suspend ConnectionMonitorEndpointFilterItemArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConnectionMonitorEndpointFilterItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument List of items in the filter.
     */
    @JvmName("wpnafxvgajlqgkfc")
    public suspend
    fun items(argument: suspend ConnectionMonitorEndpointFilterItemArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConnectionMonitorEndpointFilterItemArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param values List of items in the filter.
     */
    @JvmName("ytimqngymnxfxqqu")
    public suspend fun items(vararg values: ConnectionMonitorEndpointFilterItemArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param value The behavior of the endpoint filter. Currently only 'Include' is supported.
     */
    @JvmName("axclhajlpgucurmo")
    public suspend fun type(`value`: Either<String, ConnectionMonitorEndpointFilterType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The behavior of the endpoint filter. Currently only 'Include' is supported.
     */
    @JvmName("iwiygqovenmfoyis")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConnectionMonitorEndpointFilterType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The behavior of the endpoint filter. Currently only 'Include' is supported.
     */
    @JvmName("tsppdruyrqeybsfu")
    public fun type(`value`: ConnectionMonitorEndpointFilterType) {
        val toBeMapped = Either.ofRight<String, ConnectionMonitorEndpointFilterType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ConnectionMonitorEndpointFilterArgs = ConnectionMonitorEndpointFilterArgs(
        items = items,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ConnectionMonitorEndpointFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ConnectionMonitorEndpointFilterType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes the connection monitor endpoint filter.
 * @property items List of items in the filter.
 * @property type The behavior of the endpoint filter. Currently only 'Include' is supported.
 */
public data class ConnectionMonitorEndpointFilterArgs(
    public val items: Output<List<ConnectionMonitorEndpointFilterItemArgs>>? = null,
    public val type: Output<Either<String, ConnectionMonitorEndpointFilterType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterArgs =
        com.pulumi.azurenative.network.inputs.ConnectionMonitorEndpointFilterArgs.builder()
            .items(items?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ConnectionMonitorEndpointFilterArgs].
 */
@PulumiTagMarker
public class ConnectionMonitorEndpointFilterArgsBuilder internal constructor() {
    private var items: Output<List<ConnectionMonitorEndpointFilterItemArgs>>? = null

    private var type: Output<Either<String, ConnectionMonitorEndpointFilterType>>? = null

    /**
     * @param value List of items in the filter.
     */
    @JvmName("hysbddnshaprikqb")
    public suspend fun items(`value`: Output<List<ConnectionMonitorEndpointFilterItemArgs>>) {
        this.items = value
    }

    @JvmName("bywwpuqsbodinqcc")
    public suspend fun items(vararg values: Output<ConnectionMonitorEndpointFilterItemArgs>) {
        this.items = Output.all(values.asList())
    }

    /**
     * @param values List of items in the filter.
     */
    @JvmName("ejqglvhjtlmxfvgf")
    public suspend fun items(values: List<Output<ConnectionMonitorEndpointFilterItemArgs>>) {
        this.items = Output.all(values)
    }

    /**
     * @param value The behavior of the endpoint filter. Currently only 'Include' is supported.
     */
    @JvmName("urvyohyemerxafiy")
    public suspend fun type(`value`: Output<Either<String, ConnectionMonitorEndpointFilterType>>) {
        this.type = value
    }

    /**
     * @param value List of items in the filter.
     */
    @JvmName("rfyijonoaulushsp")
    public suspend fun items(`value`: List<ConnectionMonitorEndpointFilterItemArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param argument List of items in the filter.
     */
    @JvmName("dpaotqavtcvngxyo")
    public suspend
    fun items(argument: List<suspend ConnectionMonitorEndpointFilterItemArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConnectionMonitorEndpointFilterItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument List of items in the filter.
     */
    @JvmName("mfawyiporaxgpajb")
    public suspend fun items(
        vararg
        argument: suspend ConnectionMonitorEndpointFilterItemArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConnectionMonitorEndpointFilterItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param argument List of items in the filter.
     */
    @JvmName("xyevahtcgbudumjq")
    public suspend
    fun items(argument: suspend ConnectionMonitorEndpointFilterItemArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConnectionMonitorEndpointFilterItemArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.items = mapped
    }

    /**
     * @param values List of items in the filter.
     */
    @JvmName("xivrdmyvnnhaunkm")
    public suspend fun items(vararg values: ConnectionMonitorEndpointFilterItemArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.items = mapped
    }

    /**
     * @param value The behavior of the endpoint filter. Currently only 'Include' is supported.
     */
    @JvmName("akshgmxxvscevbad")
    public suspend fun type(`value`: Either<String, ConnectionMonitorEndpointFilterType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The behavior of the endpoint filter. Currently only 'Include' is supported.
     */
    @JvmName("jengukgfmojwwsnw")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConnectionMonitorEndpointFilterType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The behavior of the endpoint filter. Currently only 'Include' is supported.
     */
    @JvmName("bfkjsqbxojabgceq")
    public fun type(`value`: ConnectionMonitorEndpointFilterType) {
        val toBeMapped = Either.ofRight<String, ConnectionMonitorEndpointFilterType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ConnectionMonitorEndpointFilterArgs = ConnectionMonitorEndpointFilterArgs(
        items = items,
        type = type,
    )
}
